# remirepo/Fedora spec file for php-zendframework-zend-captcha
#
# Copyright (c) 2015-2017 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global bootstrap    0
%global gh_commit    2d56293a5ae3e45e7c8ee7030aa8b305768d8014
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     zendframework
%global gh_project   zend-captcha
%global php_home     %{_datadir}/php
%global library      Captcha
%if %{bootstrap}
%global with_tests   0%{?_with_tests:1}
%else
%global with_tests   0%{!?_without_tests:1}
%endif

Name:           php-%{gh_owner}-%{gh_project}
Version:        2.7.1
Release:        4%{?dist}
Summary:        Zend Framework %{library} component

Group:          Development/Libraries
License:        BSD
URL:            https://zendframework.github.io/%{gh_project}/
Source0:        %{gh_commit}/%{name}-%{version}-%{gh_short}.tgz
Source1:        makesrc.sh

BuildArch:      noarch
# Tests
%if %{with_tests}
BuildRequires:  php(language) >= 5.6
BuildRequires:  php-date
BuildRequires:  php-gd
BuildRequires:  php-spl
BuildRequires:  php-autoloader(%{gh_owner}/zend-math)           >= 2.5
BuildRequires:  php-autoloader(%{gh_owner}/zend-stdlib)         >= 2.5
# From composer, "require-dev": {
#        "zendframework/zend-session": "^2.6",
#        "zendframework/zend-text": "^2.6",
#        "zendframework/zend-validator": "^2.6",
#        "zendframework/zendservice-recaptcha": "^3.0",
#        "zendframework/zend-coding-standard": "~1.0.0",
#        "phpunit/PHPUnit": "~4.8"
BuildRequires:  php-autoloader(%{gh_owner}/zend-session)        >= 2.6
BuildRequires:  php-autoloader(%{gh_owner}/zend-text)           >= 2.6
BuildRequires:  php-autoloader(%{gh_owner}/zend-validator)      >= 2.6
BuildRequires:  php-autoloader(%{gh_owner}/zendservice-recaptcha) >= 3.0
BuildRequires:  php-composer(phpunit/phpunit)                   >= 4.8
%endif
# Autoloader
BuildRequires:  php-fedora-autoloader-devel

# From composer, "require": {
#        "php": "^5.6 || ^7.0",
#        "zendframework/zend-math": "^2.6 || ^3.0",
#        "zendframework/zend-stdlib": "^2.7 || ^3.0"
Requires:       php(language) >= 5.6
%if ! %{bootstrap}
Requires:       php-autoloader(%{gh_owner}/zend-math)           >= 2.6
Requires:       php-autoloader(%{gh_owner}/zend-math)           <  4
Requires:       php-autoloader(%{gh_owner}/zend-stdlib)         >= 2.7
Requires:       php-autoloader(%{gh_owner}/zend-stdlib)         <  4
# From composer, "suggest": {
#        "zendframework/zend-i18n-resources": "Translations of captcha messages",
#        "zendframework/zend-session": "Zend\\Session component",
#        "zendframework/zend-text": "Zend\\Text component",
#        "zendframework/zend-validator": "Zend\\Validator component",
#        "zendframework/zendservice-recaptcha": "ZendService\\ReCaptcha component"
%if 0%{?fedora} >= 21
Suggests:       php-autoloader(%{gh_owner}/zend-i18n-resources)
Suggests:       php-autoloader(%{gh_owner}/zend-session)
Suggests:       php-autoloader(%{gh_owner}/zend-text)
Suggests:       php-autoloader(%{gh_owner}/zend-validator)
Suggests:       php-autoloader(%{gh_owner}/zendservice-recaptcha)
%endif
%endif
# Autoloader
Requires:       php-composer(fedora/autoloader)
# From phpcompatinfo report for version 2.5.2
Requires:       php-date
Requires:       php-gd
Requires:       php-spl

Obsoletes:      php-ZendFramework2-%{library} < 2.5
Provides:       php-ZendFramework2-%{library} = %{version}
Provides:       php-composer(%{gh_owner}/%{gh_project}) = %{version}
Provides:       php-autoloader(%{gh_owner}/%{gh_project}) = %{version}


%description
Zend\Captcha component is able to manage “Completely Automated Public
Turing test to tell Computers and Humans Apart” (CAPTCHA); it is used
as a challenge-response to ensure that the individual submitting
information is a human and not an automated process. Typically, a captcha
is used with form submissions where authenticated users are not necessary,
but you want to prevent spam submissions.

Documentation: https://zendframework.github.io/%{gh_project}/


%prep
%setup -q -n %{gh_project}-%{gh_commit}

mv LICENSE.md LICENSE


%build
: Generate autoloader
phpab --template fedora --output src/autoload.php src
cat << 'EOF' | tee -a src/autoload.php
\Fedora\Autoloader\Dependencies::required([
    '%{php_home}/Zend/Math/autoload.php',
    '%{php_home}/Zend/Stdlib/autoload.php',
]);
\Fedora\Autoloader\Dependencies::optional([
    '%{php_home}/Zend/I18n/Translator/autoload.php',
    '%{php_home}/Zend/Session/autoload.php',
    '%{php_home}/Zend/Text/autoload.php',
    '%{php_home}/Zend/Validator/autoload.php',
    '%{php_home}/ZendService/ReCaptcha/autoload.php',
]);
EOF


%install
mkdir -p   %{buildroot}%{php_home}/Zend/
cp -pr src %{buildroot}%{php_home}/Zend/%{library}


%check
%if %{with_tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require_once '%{buildroot}%{php_home}/Zend/%{library}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('ZendTest\\%{library}\\', dirname(__DIR__) . '/test');
EOF

ret=0
for cmd in php php56 php70 php71 php72; do
  if which $cmd; then
    $cmd %{_bindir}/phpunit || ret=1
  fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.md
%doc composer.json
%{php_home}/Zend/%{library}


%changelog
* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.7.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Dec 11 2017 Remi Collet <remi@remirepo.net> - 2.7.1-3
- switch from zend-loader to fedora/autoloader

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.7.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Thu Feb 23 2017 Remi Collet <remi@fedoraproject.org> - 2.7.1-1
- update to 2.7.1

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Jun 22 2016 Remi Collet <remi@fedoraproject.org> - 2.6.0-1
- update to 2.6.0
- raise dependency on PHP 5.6

* Tue Feb 23 2016 Remi Collet <remi@fedoraproject.org> - 2.5.4-1
- update to 2.5.4
- raise dependency on zend-math >= 2.6
- raise dependency on zend-stdlib >= 2.7

* Tue Feb 23 2016 Remi Collet <remi@fedoraproject.org> - 2.5.3-1
- update to 2.5.3

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.5.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Nov 25 2015 Remi Collet <remi@fedoraproject.org> - 2.5.2-1
- update to 2.5.2
- raise dependency on PHP 5.5

* Tue Aug  4 2015 Remi Collet <remi@fedoraproject.org> - 2.5.1-1
- initial package